package services

import (
	"eta/eta_api/models"
	"eta/eta_api/models/report_approve"
	"eta/eta_api/models/smart_report"
	"fmt"
)

// GetReportClassifyTreeRecursive 递归获取报告分类树
func GetReportClassifyTreeRecursive(list []*models.Classify, parentId int) []*report_approve.ReportClassifyTreeItem {
	res := make([]*report_approve.ReportClassifyTreeItem, 0)
	for _, v := range list {
		if v.ParentId == parentId {
			t := new(report_approve.ReportClassifyTreeItem)
			t.ClassifyId = v.Id
			t.ClassifyName = v.ClassifyName
			t.ParentId = v.ParentId
			t.Children = GetReportClassifyTreeRecursive(list, v.Id)
			res = append(res, t)
		}
	}
	return res
}

// CheckReportApproveFlowChange 校验是否可变更分类
func CheckReportApproveFlowChange(reportType, classifyFirstId, classifySecondId int) (ok bool, err error) {
	var count int
	cond := ` AND classify_first_id = ? AND classify_second_id = ? AND state = ?`
	pars := make([]interface{}, 0)
	pars = append(pars, classifyFirstId, classifySecondId, models.ReportStateWaitApprove)
	switch reportType {
	case report_approve.FlowReportTypeChinese:
		ct, e := models.GetReportListCount(cond, pars, "")
		if e != nil {
			err = fmt.Errorf("GetReportListCount err: %s", e.Error())
			return
		}
		count = ct
	case report_approve.FlowReportTypeEnglish:
		ct, e := models.GetEnglishReportListCount(cond, pars, "")
		if e != nil {
			err = fmt.Errorf("GetEnglishReportListCount err: %s", e.Error())
			return
		}
		count = ct
	case report_approve.FlowReportTypeSmart:
		ob := new(smart_report.SmartReport)
		ct, e := ob.GetCountByCondition(cond, pars)
		if e != nil {
			err = fmt.Errorf("SmartReport GetCountByCondition err: %s", e.Error())
			return
		}
		count = ct
	default:
		err = fmt.Errorf("报告类型有误")
		return
	}
	if count <= 0 {
		ok = true
	}
	return
}
